@@ -17,16 +17,17 @@ import copy
 import itertools
 
 import cloudkitty.api.app
-import cloudkitty.collector.ceilometer
 import cloudkitty.collector.gnocchi
 import cloudkitty.collector.monasca
 import cloudkitty.config
+import cloudkitty.fetcher
+import cloudkitty.fetcher.keystone
+import cloudkitty.fetcher.source
 import cloudkitty.orchestrator
 import cloudkitty.service
 import cloudkitty.storage
-import cloudkitty.storage.gnocchi
-import cloudkitty.tenant_fetcher
-import cloudkitty.tenant_fetcher.keystone
+import cloudkitty.storage.v1.hybrid.backends.gnocchi
+import cloudkitty.storage.v2.gnocchi
 import cloudkitty.utils
 
 __all__ = ['list_opts']
@@ -35,16 +36,18 @@ _opts = [
     ('api', list(itertools.chain(
         cloudkitty.api.app.api_opts,))),
     ('collect', list(itertools.chain(
-        cloudkitty.utils.collect_opts))),
-    ('ceilometer_collector', list(itertools.chain(
-        cloudkitty.collector.ceilometer.ceilometer_collector_opts))),
+        cloudkitty.collector.collect_opts))),
     ('collector_monasca', list(itertools.chain(
-        cloudkitty.collector.monasca.collector_monasca_opts))),
+        cloudkitty.collector.monasca.collector_monasca_opts,
+        cloudkitty.collector.monasca.mcollector_opts))),
     ('gnocchi_collector', list(itertools.chain(
+        cloudkitty.collector.gnocchi.gcollector_opts,
         cloudkitty.collector.gnocchi.gnocchi_collector_opts))),
     ('keystone_fetcher', list(itertools.chain(
-        cloudkitty.tenant_fetcher.keystone.keystone_fetcher_opts,
-        cloudkitty.tenant_fetcher.keystone.keystone_common_opts))),
+        cloudkitty.fetcher.keystone.keystone_fetcher_opts,
+        cloudkitty.fetcher.keystone.keystone_common_opts))),
+    ('source_fetcher', list(itertools.chain(
+        cloudkitty.fetcher.source.source_fetcher_opts))),
     ('orchestrator', list(itertools.chain(
         cloudkitty.orchestrator.orchestrator_opts))),
     ('output', list(itertools.chain(
@@ -54,12 +57,12 @@ _opts = [
     ('storage', list(itertools.chain(
         cloudkitty.storage.storage_opts))),
     ('storage_gnocchi', list(itertools.chain(
-        cloudkitty.storage.gnocchi.gnocchi_storage_opts))),
-    ('tenant_fetcher', list(itertools.chain(
-        cloudkitty.tenant_fetcher.fetchers_opts))),
+        cloudkitty.storage.v1.hybrid.backends.gnocchi.gnocchi_storage_opts))),
+    ('storage_gnocchi', list(itertools.chain(
+        cloudkitty.storage.v2.gnocchi.gnocchi_storage_opts))),
     (None, list(itertools.chain(
         cloudkitty.api.app.auth_opts,
-        cloudkitty.service.service_opts)))
+        cloudkitty.service.service_opts))),
 ]
 
 
