@@ -18,6 +18,7 @@
 import abc
 import decimal
 import os
+from unittest.case import SkipTest
 
 from gabbi import fixture
 import mock
@@ -41,8 +42,10 @@ from cloudkitty.db import api as ck_db_api
 from cloudkitty import messaging
 from cloudkitty import rating
 from cloudkitty import storage
-from cloudkitty.storage.sqlalchemy import models
+from cloudkitty.storage.v1.sqlalchemy import models
 from cloudkitty import tests
+from cloudkitty.tests import test_utils
+from cloudkitty.tests.utils import is_functional_test
 from cloudkitty import utils as ck_utils
 
 
@@ -83,9 +86,10 @@ class BaseExtensionFixture(fixture.GabbiFixture):
         self.patch.return_value = fake_mgr
 
     def stop_fixture(self):
-        self.patch.assert_called_with(
-            self.namespace,
-            **self.assert_args)
+        if not is_functional_test():
+            self.patch.assert_called_with(
+                self.namespace,
+                **self.assert_args)
         self.mock.stop()
 
 
@@ -189,7 +193,7 @@ class ConfigFixture(fixture.GabbiFixture):
         conf = conf_fixture.Config().conf
         policy_opts.set_defaults(conf)
         msg_conf = conffixture.ConfFixture(conf)
-        msg_conf.transport_driver = 'fake'
+        msg_conf.transport_url = 'fake:/'
         conf.import_group('api', 'cloudkitty.api.app')
         conf.set_override('auth_strategy', self.auth_strategy)
         conf.set_override('connection', 'sqlite:///', 'database')
@@ -202,6 +206,7 @@ class ConfigFixture(fixture.GabbiFixture):
                           )
         conf.import_group('storage', 'cloudkitty.storage')
         conf.set_override('backend', 'sqlalchemy', 'storage')
+        conf.set_override('version', '1', 'storage')
         self.conf = conf
         self.conn = ck_db_api.get_instance()
         migration = self.conn.get_migration()
@@ -278,7 +283,7 @@ class BaseStorageDataFixture(fixture.GabbiFixture):
                 "begin": begin,
                 "end": end},
             "usage": {
-                "compute": [
+                "cpu": [
                     {
                         "desc": {
                             "dummy": True,
@@ -292,7 +297,7 @@ class BaseStorageDataFixture(fixture.GabbiFixture):
                 "begin": begin,
                 "end": end},
             "usage": {
-                "image": [
+                "image.size": [
                     {
                         "desc": {
                             "dummy": True,
@@ -313,7 +318,7 @@ class BaseStorageDataFixture(fixture.GabbiFixture):
             return_value=dict())
         with auth:
             with session:
-                self.storage = storage.get_storage()
+                self.storage = storage.get_storage(conf=test_utils.load_conf())
         self.storage.init()
         self.initialize_data()
 
@@ -331,28 +336,19 @@ class StorageDataFixture(BaseStorageDataFixture):
         nodata_duration = (24 * 3 + 12) * 3600
         tenant_list = ['8f82cc70-e50c-466e-8624-24bdea811375',
                        '7606a24a-b8ad-4ae0-be6c-3d7a41334a2e']
-        for tenant in tenant_list:
-            for i in range(INITIAL_TIMESTAMP,
-                           INITIAL_TIMESTAMP + nodata_duration,
-                           3600):
-                self.storage.nodata(i, i + 3600, tenant)
         data_ts = INITIAL_TIMESTAMP + nodata_duration + 3600
         data_duration = (24 * 2 + 8) * 3600
         for i in range(data_ts,
                        data_ts + data_duration,
                        3600):
             data = self.create_fake_data(i, i + 3600)
-            self.storage.append(data, tenant_list[0])
+            self.storage.push(data, tenant_list[0])
         half_duration = int(data_duration / 2)
         for i in range(data_ts,
                        data_ts + half_duration,
                        3600):
             data = self.create_fake_data(i, i + 3600)
-            self.storage.append(data, tenant_list[1])
-        for i in range(data_ts + half_duration + 3600,
-                       data_ts + data_duration,
-                       3600):
-            self.storage.nodata(i, i + 3600, tenant_list[1])
+            self.storage.push(data, tenant_list[1])
 
 
 class NowStorageDataFixture(BaseStorageDataFixture):
@@ -362,8 +358,8 @@ class NowStorageDataFixture(BaseStorageDataFixture):
                        begin + 3600 * 12,
                        3600):
             data = self.create_fake_data(i, i + 3600)
-            self.storage.append(data,
-                                '3d9a1b33-482f-42fd-aef9-b575a3da9369')
+            self.storage.push(data,
+                              '3d9a1b33-482f-42fd-aef9-b575a3da9369')
 
 
 class CORSConfigFixture(fixture.GabbiFixture):
@@ -387,6 +383,27 @@ class CORSConfigFixture(fixture.GabbiFixture):
         cfg.ConfigOpts.GroupAttr.__getattr__ = self._original_call_method
 
 
+class MetricsConfFixture(fixture.GabbiFixture):
+    """Inject Metrics configuration mock to the get_metrics_conf() function"""
+
+    def start_fixture(self):
+        self._original_function = ck_utils.load_conf
+        ck_utils.load_conf = mock.Mock(
+            return_value=tests.samples.METRICS_CONF,
+        )
+
+    def stop_fixture(self):
+        """Remove the get_metrics_conf() monkeypatch."""
+        ck_utils.load_conf = self._original_function
+
+
+class SkipIfFunctional(fixture.GabbiFixture):
+
+    def start_fixture(self):
+        if is_functional_test():
+            raise SkipTest
+
+
 def setup_app():
     messaging.setup()
     # FIXME(sheeprine): Extension fixtures are interacting with transformers
