@@ -17,6 +17,7 @@
 #
 import copy
 import decimal
+import testtools
 
 import mock
 from oslo_utils import uuidutils
@@ -24,6 +25,8 @@ from oslo_utils import uuidutils
 from cloudkitty.rating import hash
 from cloudkitty.rating.hash.db import api
 from cloudkitty import tests
+from cloudkitty.tests.utils import is_functional_test
+
 
 TEST_TS = 1388577600
 FAKE_UUID = '6c1b8a30-797f-4b7e-ad66-9879b79059fb'
@@ -81,6 +84,7 @@ CK_RESOURCES_DATA = [{
                     "unit": "instance"}}]}}]
 
 
+@testtools.skipIf(is_functional_test(), 'Not a functional test')
 class HashMapRatingTest(tests.TestCase):
     def setUp(self):
         super(HashMapRatingTest, self).setUp()
