@@ -19,11 +19,14 @@ import datetime
 import decimal
 import fractions
 import itertools
+import testtools
 import unittest
 
 import mock
 from oslo_utils import timeutils
 
+from cloudkitty.tests.samples import DEFAULT_METRICS_CONF
+from cloudkitty.tests.utils import is_functional_test
 from cloudkitty import utils as ck_utils
 
 
@@ -31,6 +34,7 @@ def iso2dt(iso_str):
     return timeutils.parse_isotime(iso_str)
 
 
+@testtools.skipIf(is_functional_test(), 'Not a functional test')
 class UtilsTimeCalculationsTest(unittest.TestCase):
     def setUp(self):
         self.date_ts = 1416219015
@@ -141,6 +145,7 @@ class UtilsTimeCalculationsTest(unittest.TestCase):
         self.assertEqual(calc_dt, check_dt)
 
 
+@testtools.skipIf(is_functional_test(), 'Not a functional test')
 class ConvertUnitTest(unittest.TestCase):
     """Class testing the convert_unit and num2decimal function"""
     possible_args = [
@@ -195,3 +200,7 @@ class ConvertUnitTest(unittest.TestCase):
     def test_convert_decimal(self):
         result = ck_utils.num2decimal(decimal.Decimal(2))
         self.assertEqual(result, decimal.Decimal(2))
+
+
+def load_conf(*args):
+    return DEFAULT_METRICS_CONF
