@@ -173,6 +173,13 @@ function configure_cloudkitty {
     iniset $CLOUDKITTY_CONF output basepath $CLOUDKITTY_OUTPUT_BASEPATH
     iniset $CLOUDKITTY_CONF output pipeline $CLOUDKITTY_OUTPUT_PIPELINE
 
+    # storage
+    iniset $CLOUDKITTY_CONF storage backend $CLOUDKITTY_STORAGE_BACKEND
+    iniset $CLOUDKITTY_CONF storage version $CLOUDKITTY_STORAGE_VERSION
+    if [ "$CLOUDKITTY_STORAGE_BACKEND" != "sqlalchemy" ]; then
+        iniset $CLOUDKITTY_CONF storage_${CLOUDKITTY_STORAGE_BACKEND} auth_section authinfos
+    fi
+
     # database
     local dburl=`database_connection_url cloudkitty`
     iniset $CLOUDKITTY_CONF database connection $dburl
@@ -185,6 +192,13 @@ function configure_cloudkitty {
     fi
 }
 
+function wait_for_gnocchi() {
+    local gnocchi_url=$(openstack --os-cloud devstack-admin endpoint list --service metric --interface public -c URL -f value)
+    if ! wait_for_service $SERVICE_TIMEOUT $gnocchi_url; then
+       die $LINENO "Waited for gnocchi too long."
+    fi
+}
+
 # create_cloudkitty_cache_dir() - Part of the init_cloudkitty() process
 function create_cloudkitty_cache_dir {
     # Create cache dir
@@ -226,6 +240,9 @@ function init_cloudkitty {
     $CLOUDKITTY_BIN_DIR/cloudkitty-dbsync upgrade
 
     # Init the storage backend
+    if [ $CLOUDKITTY_STORAGE_BACKEND == 'hybrid' ]; then
+        wait_for_gnocchi
+    fi
     $CLOUDKITTY_BIN_DIR/cloudkitty-storage-init
 
     create_cloudkitty_cache_dir
@@ -248,8 +265,6 @@ function start_cloudkitty {
         echo_summary "Waiting 15s for cloudkitty-processor to authenticate against keystone before apache is restarted."
         sleep 15s
         restart_apache_server
-        tail_log cloudkitty /var/log/$APACHE_NAME/cloudkitty.log
-        tail_log cloudkitty-api /var/log/$APACHE_NAME/cloudkitty_access.log
     fi
     echo "Waiting for ck-api ($CLOUDKITTY_SERVICE_HOST:$CLOUDKITTY_SERVICE_PORT) to start..."
     if ! wait_for_service $SERVICE_TIMEOUT $CLOUDKITTY_SERVICE_PROTOCOL://$CLOUDKITTY_SERVICE_HOST:$CLOUDKITTY_SERVICE_PORT; then
